@@ -4,10 +4,11 @@ import shutil
 import unittest
 
 import pytest
+from trashcli.fs import FileRemover, read_file
 
-from .files import make_unreadable_file, make_unreadable_dir, make_readable
-from trashcli.fs import read_file, FileRemover
-from .support import MyPath
+from .support.files import make_unreadable_file, make_unreadable_dir, \
+    make_readable
+from .support.my_path import MyPath
 
 
 @pytest.mark.slow
